==> haskell-jira-wiki-markup-1.5.1-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-jira-wiki-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 jira-wiki-markup
version:              1.5.1
visibility:           public
id:                   jira-wiki-markup-1.5.1-7KcKspO1Ndz5QGKrFyfGZs
key:                  jira-wiki-markup-1.5.1-7KcKspO1Ndz5QGKrFyfGZs
license:              MIT
copyright:            © 2019–2023 Albert Krewinkel
maintainer:           tarleb@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/jira-wiki-markup
synopsis:             Handle Jira wiki markup
description:
    Parse jira wiki text into an abstract syntax tree for easy
    transformation to other formats.

category:             Text
abi:                  91824fa4df479dc1f4fbc388db4d54d4
exposed:              True
exposed-modules:
    Text.Jira.Markup Text.Jira.Parser Text.Jira.Parser.Block
    Text.Jira.Parser.Core Text.Jira.Parser.Inline
    Text.Jira.Parser.PlainText Text.Jira.Parser.Shared
    Text.Jira.Printer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/jira-wiki-markup-1.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/jira-wiki-markup-1.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/jira-wiki-markup-1.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-jira-wiki-markup
hs-libraries:         HSjira-wiki-markup-1.5.1-7KcKspO1Ndz5QGKrFyfGZs
depends:              base-4.17.2.1 mtl-2.2.2 parsec-3.1.16.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-jira-wiki-markup/html/jira-wiki-markup.haddock

haddock-html:         /usr/share/doc/haskell-jira-wiki-markup/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jira-wiki-markup-1.5.1-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-jira-wiki-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 jira-wiki-markup
version:              1.5.1
visibility:           public
id:                   jira-wiki-markup-1.5.1-4iPlzrqUf9pEItxRrlFPzD
key:                  jira-wiki-markup-1.5.1-4iPlzrqUf9pEItxRrlFPzD
license:              MIT
copyright:            © 2019–2023 Albert Krewinkel
maintainer:           tarleb@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/jira-wiki-markup
synopsis:             Handle Jira wiki markup
description:
    Parse jira wiki text into an abstract syntax tree for easy
    transformation to other formats.

category:             Text
abi:                  35b358ce25b17e7a99e8cf0bfe52b52f
exposed:              True
exposed-modules:
    Text.Jira.Markup Text.Jira.Parser Text.Jira.Parser.Block
    Text.Jira.Parser.Core Text.Jira.Parser.Inline
    Text.Jira.Parser.PlainText Text.Jira.Parser.Shared
    Text.Jira.Printer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/jira-wiki-markup-1.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/jira-wiki-markup-1.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/jira-wiki-markup-1.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-jira-wiki-markup
hs-libraries:         HSjira-wiki-markup-1.5.1-4iPlzrqUf9pEItxRrlFPzD
depends:              base-4.17.2.1 mtl-2.2.2 parsec-3.1.16.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-jira-wiki-markup/html/jira-wiki-markup.haddock

haddock-html:         /usr/share/doc/haskell-jira-wiki-markup/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
